#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Dec 10 15:07:10 2020

@author: samuel.niang@cern.ch
"""

from GBARpy.Main_window import MainWindow
win = MainWindow()
win.mainloop()
win.quit()
